@@ -65,6 +65,21 @@ class Materiel_Form(ModelForm):
       model = Materiel
       fields = '__all__'
       exclude = ('id','Pretes','Achetes','Perdus')
+
+   def clean(self):
+      """
+      Au-delà des vérifications usuelles,
+      vérifie que la liste d'options/spécialités est vide au cas où
+      un manuel est dans le tronc commun
+      """
+      ModelForm.clean(self)
+      tronc = self.cleaned_data.get("tronc")
+      lib_option = self.cleaned_data.get("lib_option")
+      if tronc and lib_option:
+         raise ValidationError(
+            _("Un livre ne peut pas être à la fois dans le tronc commun"
+              " et définir des options SIÈCLE"))
+      return
   
 class Eleves_Form(ModelForm):
    classe = forms.ModelChoiceField(queryset=Classes.classes_importantes())
@@ -79,6 +94,7 @@ class Eleves_Form(ModelForm):
                 'Lib_Mat_Enseignee_9','Lib_Mat_Enseignee_10',
                 'Tel_Portable', 'Adresse_Repr_Leg',
                 'Tel_Portable_Repr_Leg', 'Tel_Portable_Autre_Repr_Leg',
+                'message',
                 'a_verifier')
       labels = {f.name: _(f.verbose_name) for f in Eleves._meta.fields}
       widgets = {
