@@ -799,15 +799,30 @@ def sauvegarde(request):
     def sauvegarde_date(path):
         """
         renvoie la date et l'heure de création d'un fichier de sauvegarde
+        sachant que le nom d'une sauvegarde est calqué sur le modèle
+        db-2025-09-30_T_01-20-01.sqlite3.zip
         """
-        d = datetime.fromtimestamp(path.stat().st_mtime)
+        pattern = re.compile(
+            r".*db-(\d+)-(\d+)-(\d+)_T_(\d+)-(\d+)-(\d+).sqlite3.zip")
+        m = pattern.match(str(path))
+        if m : # on déduit une date du nom de fichier
+            d = datetime(
+                year   =int(m.group(1)),
+                month  =int(m.group(2)),
+                day    =int(m.group(3)),
+                hour   =int(m.group(4)),
+                minute =int(m.group(5)),
+                second =int(m.group(6))
+            )
+        else: # si le nom de fichier ne va pas on prend la date du système
+            d = datetime.fromtimestamp(path.stat().st_mtime)
         wd = (d.strftime("%A")+"___________________")[:10]
         return wd + d.strftime("%d/%m/%Y à %H:%M")
         
     p = pathlib.Path(MEDIA_ROOT, "sauvegarde")
     sauvegardes_faites = {
         MEDIA_URL + "sauvegarde/" + path.name: sauvegarde_date(path) \
-        for path in p.glob('*.zip')
+        for path in sorted(p.glob('*.zip'))
     }
     return render_common(
         request,'gestion/sauvegarde.html',
@@ -1597,6 +1612,7 @@ def choix_eleves(request):
         'gestion/choix_eleves.html',
         _("Actions sur des élèves à choisir"),
         {
+            "classes": Classes.classes_importantes(),
             "aide": "choix_eleves",
         })
 
