@@ -494,3 +494,42 @@ def listes_eleves(request):
         filename=_("listes_eleves.pdf"),
     )
     
+def messages_eleves(request):
+    """
+    Produit un document avec tous les messages non vides destinés aux
+    élèves
+    """
+    eleves = Eleves.objects.exclude(message="").order_by(
+        'Lib_Structure','NomPrenomEleve')
+    for e in eleves:
+        e.message = "</para><para>".join(e.message.split("\n"))
+    return render_pdf(
+        request,
+        'gestion/messages_eleves.rml', {
+            "date": datetime.now().strftime("%d %b %Y"),
+            "eleves": eleves,
+            "colWidths": "6cm,12cm",
+        },
+        filename=_("listes_eleves.pdf"),
+    )
+    
+def pqcl(request, ident):
+    """
+    Fonction de rappel pour la routine Javascript pour_qui_ce_livre
+    Produit un document avec tous les élèves devant recevoir un livre
+    @param  ident id pour le livre
+    """
+    manuel = Materiel.objects.get(id=ident)
+    eleves = manuel.pour_qui_ce_livre()
+    eleves.sort(key=lambda e: e.NomPrenomEleve)
+    eleves.sort(key=lambda e: e.Lib_Structure)
+    return render_pdf(
+        request,
+        'gestion/pour_qui_ce_livre.rml', {
+            "date": datetime.now().strftime("%d %b %Y"),
+            "livre": manuel,
+            "eleves": eleves,
+        },
+        filename=_("pour_qui_ce_livre.pdf"),
+    )
+    
